@@ -65,19 +65,10 @@
 #ifndef ARRAYS_H
 #define ARRAYS_H
 
-
-/* Array2D */
-#include <Arrays/include/STK_Array2DPoint.h>
-#include <Arrays/include/STK_Array2DVector.h>
-#include <Arrays/include/STK_Array2D.h>
-#include <Arrays/include/STK_Array2DSquare.h>
-#include <Arrays/include/STK_Array2DDiagonal.h>
-#include <Arrays/include/STK_Array2DUpperTriangular.h>
-#include <Arrays/include/STK_Array2DLowerTriangular.h>
-#include <Arrays/include/STK_Array2DNumber.h>
-
-/* Functors applied to  Array2D */
-#include <Arrays/include/STK_Array2D_Functors.h>
+/* Uni-dimensionnal Array. */
+#include <Arrays/include/STK_Array1D.h>
+#include <Arrays/include/STK_SArray1D.h>
+#include <Arrays/include/STK_Array1D_InnerIterator.h>
 
 /* CArray */
 #include <Arrays/include/STK_CArray.h>
@@ -89,10 +80,30 @@
 /* constant Arrays */
 #include <Arrays/include/STK_Const_Arrays.h>
 
+/* Array2D */
+#include <Arrays/include/STK_Array2D.h>
+#include <Arrays/include/STK_Array2DPoint.h>
+#include <Arrays/include/STK_Array2DVector.h>
+#include <Arrays/include/STK_Array2DSquare.h>
+#include <Arrays/include/STK_Array2DDiagonal.h>
+#include <Arrays/include/STK_Array2DUpperTriangular.h>
+#include <Arrays/include/STK_Array2DLowerTriangular.h>
+#include <Arrays/include/STK_Array2DNumber.h>
+
+/* Functors applied to  Array2D */
+#include <Arrays/include/STK_Array2D_Functors.h>
+
+/* SArray2D */
+#include <Arrays/include/STK_SArray2DPoint.h>
+#include <Arrays/include/STK_SArray2DVector.h>
+#include <Arrays/include/STK_SArray2D.h>
+#include <Arrays/include/STK_SArray2DSquare.h>
+#include <Arrays/include/STK_SArray2DDiagonal.h>
+#include <Arrays/include/STK_SArray2DUpperTriangular.h>
+#include <Arrays/include/STK_SArray2DLowerTriangular.h>
+#include <Arrays/include/STK_SArray2DNumber.h>
+
 /* display arrays and expressions */
 #include <Arrays/include/STK_Display.h>
 
-/* Uni-dimensionnal Array. */
-#include <Arrays/include/STK_Array1D.h>
-
 #endif  /* ARRAYS_H */
